# Examples

This directory contains examples of how to use `routingblocks`:

* ils: A simple ILS for the EVRP-TW-PR.
* alns: A simple ALNS for the EVRP-TW-PR.
* evrptw: An example implementation of a more sophisticated ALNS-based algorithm for the EVRP-TW-PR problem.

## Running

Before running any of the examples, make sure that you've installed the example's requirements.
Then, to run any of the python examples:

```bash
python -m <example_name> -h
```

You can find further information in the respective example's README.